#include "osl/effect/moveSignature.h"
#include "osl/oslConfig.h"
#include <iomanip>
#include <iostream>
#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>

using namespace osl;
using namespace osl::effect;

class moveSignatureTest : public CppUnit::TestFixture {
  CPPUNIT_TEST_SUITE( moveSignatureTest );
  CPPUNIT_TEST( testShow );
  CPPUNIT_TEST_SUITE_END();
 public:
  moveSignatureTest();
  void testShow();
};


CPPUNIT_TEST_SUITE_REGISTRATION(moveSignatureTest);

moveSignatureTest::moveSignatureTest(){
}

void moveSignatureTest::testShow(){
  if(! OslConfig::verbose()) return;
  for(int i=PTYPEO_MIN;i<=PTYPEO_MAX;i++){
    PtypeO ptypeO=static_cast<PtypeO>(i);
    std::cout << ptypeO << "," << Move_Signature_Table.getSignature(ptypeO) << std::endl;
  }
}
